function copy () {
            // انتخاب محتوای متنی مورد نظر برای کپی
            var textToCopy = document.getElementById("text-to-copy").innerText;

            // ایجاد یک محیط موقت برای کپی کردن محتوا
            var tempInput = document.createElement("input");
            tempInput.setAttribute("value", textToCopy);
            document.body.appendChild(tempInput);

            // انتخاب محتوا در محیط موقت
            tempInput.select();
            tempInput.setSelectionRange(0, 99999); // برای مرورگرهای مختلف

            // اجرای دستور کپی
            document.execCommand("copy");

            // حذف محیط موقت
            document.body.removeChild(tempInput);

            document.getElementById("text-message").innerText = "کپی شد!";
        }