/*slider*/

#slider {
    /* z-index: -1020; */
    border-radius: 2rem;

}

.slider-img {
    width: 100%;
    object-fit: cover;
    max-height: 60vh;

    position: relative;
    z-index: -1;
    height: 59vmin;

    /* place holder start */
    background-image: linear-gradient(90deg, rgba(255, 255, 255, 0) 15%, #f0f0f0 50%, rgba(255, 255, 255, 0) 85%);
    background-repeat: no-repeat;
    background-size: 50%;
    -webkit-animation: test 4s infinite;
    /* Chrome, Safari, Opera */
    animation: test 4s infinite;
    /* place holder end */


}

.img-gradiant {
    background: rgb(0, 0, 0);

    background: linear-gradient(15deg, #1c1c1c 5%, rgba(255, 255, 255, 0.14) 50%);
    /* linear-gradient(0deg, var(--color-sliderGradiant) 12%, rgba(255, 255, 255, 0) 59%); */
}

#slider-btn {
    visibility: hidden;
}

.slider-text {
    color: #ffffff;
    margin-left: -20px;
    /*margin-bottom: -20px;*/
    font-size: 30px;
    text-transform: uppercase;
    font-weight: bold;
}

.main-img-container {
    width: 100%;
    max-width: 600px; /* حداکثر عرض قاب */
    height: 29vmin; /* ارتفاع قاب */
    overflow: hidden;
    position: relative;
}

.main-img-container img {
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    min-width: 100%;
    min-height: 100%;
    object-fit: cover;
    z-index: -1;
}

.main-img-container div {
    position: absolute;
    right: 25%;
    bottom: 0.15rem;
    left: -14%;
    padding-top: 1.25rem;
    padding-bottom: 1.25rem;
    color: #fff;
    text-align: center;

}

.main-img-container div span {
    font-size: 20px;
}

/* استایل‌های موبایل */
@media only screen and (max-width: 600px) {
    .main-img-container {
        height: 55px; /* ارتفاع قاب */
    }

    .slider-img {
        height: 30vh;
    }

    .main-img-container div {
        right: 40%;
        bottom: -0.55rem;
    }



    .product-title {
        font-size: 15px;
        font-weight: normal;
    }
}

/* استایل‌های دسکتاپ */
@media only screen and (min-width: 601px) {


    .product-title {
        font-size: 18px;
        font-weight: normal;
    }
}

.product-container {
    width: 100%;
    overflow: hidden;
    position: relative;
    aspect-ratio: 1/1;
}



.product-container img {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    object-fit: cover;
    z-index: -1;
    transition: transform 0.5s ease; /* اضافه کردن انیمیشن برای افکت زوم */
}

.product-container:hover img {
    transform: scale(1.1); /* زوم کردن تصویر وقتی موس روی آن قرار می‌گیرد */
}


.clickable {
    cursor: pointer;
}

.accordion-button:focus {
    outline: none;
    box-shadow: none;
}


.range-container {
    position: relative;
    width: 100%;
    height: 50px;
}

.form-range {
    position: absolute;
    width: 100%;
    height: 50px;
    opacity: 0;
}

.range-track {
    position: absolute;
    top: 50%;
    left: 0;
    width: 100%;
    height: 4px;
    background: #ddd;
    transform: translateY(-50%);
}

.range-thumb {
    position: absolute;
    top: 50%;
    width: 20px;
    height: 20px;
    background: #007bff;
    border-radius: 50%;
    transform: translateY(-50%);
}