@font-face {
    font-family: yekan;
    src: url(../font/yaken/BYekan.ttf);
    src: url(../font/yaken/BYekan-Bold.ttf);

}

@font-face {
    font-family: yekanFaNum;
    src: url(../font/yaken/yekan-fa.ttf);
}

@font-face {
    font-family: vazirFont;
    src: url(../font/vazir/Vazirmatn-Regular.ttf);
    src: url(../font/vazir/Vazir-Regular-FD-WOL.ttf);

}

body {
    font-family: yekan;
}

a {
    text-decoration: none;
    color: #757575;
}

.persian-number {
    font-family: vazirFont;
}

.container-image {
    width: 100%; /* عرض ثابت برای مربع */
    height: 100px; /* ارتفاع ثابت برای مربع */
    overflow: hidden; /* جلوگیری از نمایش قسمت‌های اضافی تصویر */
    object-fit: cover; /* تنظیم کراپ کردن تصویر */

}

.bg-purple {
    background-color: #6f42c1 !important;
}

@media screen and (min-width: 581px) {
    .container-image {
        width: 100%; /* عرض ثابت برای مربع */
        height: 73%; /* ارتفاع ثابت برای مربع */
        overflow: hidden; /* جلوگیری از نمایش قسمت‌های اضافی تصویر */
        object-fit: cover; /* تنظیم کراپ کردن تصویر */

    }

    .post-image {
        height: 30rem !important;
    }

    .post-card {
        width: 71%;
    }
}


/*post*/
.post-image {
    width: 100%;
    height: 11rem;
    object-fit: cover;
}

.h1-header {
    font-weight: bold;
}

/*post component home*/
.post-image-component {
    width: 100%;
    height: 220px;
    object-fit: cover;
}

.sticky {
    position: fixed;
    bottom: 0;
    width: 100%;
    z-index: 20;
}

.bg-white {
    background-color: #eeeeee;
}

#myHeader span {
    font-size: small;
}

.avatar-container {
    width: 70px;
    height: 70px;
    position: relative;
    display: inline-block;
}

.avatar-container img {
    width: inherit;
    margin-top: 18px;

}

.pulse {
    z-index: -1;
    position: absolute;
    top: 50%;
    left: 50%;
    width: 100%;
    height: 100%;
    background: rgba(197, 197, 197, 0.5);
    border-radius: 50%;
    transform: translate(-50%, -50%);
    animation: pulse-animation 2s infinite;
}

@keyframes pulse-animation {
    0% {
        transform: translate(-50%, -50%) scale(1);
        opacity: 1;
    }
    100% {
        transform: translate(-50%, -50%) scale(2);
        opacity: 0;
    }
}
.img-white{
      -webkit-filter: invert(100%); /* Safari/Chrome */
    filter: invert(100%);
}