var w = window.innerWidth;
var h = window.innerHeight;
if (w >= 991) {
    document.getElementById("md-cart-area").innerHTML = document.getElementById("cart-area").innerHTML + document.getElementById("services-area").innerHTML;
    document.getElementById("cart-area").innerHTML = "";
    document.getElementById("services-area").innerHTML = "";

    let table = document.getElementById("info-table")
    table.classList.remove("table-striped")
    table.classList.remove("table-hover")
    table.classList.add("w-25")

} else {
    document.getElementById("product-count-container").classList.add("shadow-lg");
}

