/* استایل‌های موبایل */
@media only screen and (max-width: 600px) {
    .cart-title {
        font-size: 1rem;
    }

    .info-btn {
        width: 40px;
        font-size: 1rem;
    }

    .info-text {
        font-size: 0.65rem;

    }

    .main-title {
        font-size: 0.95rem;
    }


}

/* استایل‌های دسکتاپ */
@media only screen and (min-width: 601px) {
    .cart-title {
        font-size: 1.5rem;
    }

    .info-btn {
        width: 80px;
    }

    .info-text {
        font-size: 0.25rem;

    }

    .main-title {
        font-size: 1.25rem;
    }

.order-img-container {
    /*width: ;*/
    height: 175px;

}
}

.cart-img-container {
    /* این کد کانتینر را تعریف می‌کند */
    position: relative;
    overflow: hidden;
}

.order-img-container {
    /*width: 100px;*/
    /*height: 200px;*/
    overflow: hidden;
    position: relative;


}

.order-img-container img {
    width: 100%;
    height: auto;
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);

}

.cart-img {
    /* این کد تصویر را در وسط کانتینر قرار می‌دهد و اگر تصویر بزرگتر یا کوچکتر از کانتینر بود، آن را کراپ می‌کند */
    position: absolute;
    /*top: 0;*/
    /*left: 0;*/
    /*bottom: 0;*/
    /*right: 0;*/
    width: 100%;
    height: 100%;
    object-fit: cover;
}
